@@ -12,6 +12,19 @@ test_that("general test case", {
   expect_equal(mean(out$B), 205.07)
 })
 
+test_that("calling the function directly", {
+
+  set.seed(2435)
+
+  dag <- empty_dag() +
+    node("A", type="rnorm", mean=12, sd=10)
+  dat <- as.data.frame(sim_from_dag(dag=dag, n_sim=100))
+
+  out <- node_poisson(data=dat, parents="A", betas=0.2, intercept=1)
+
+  expect_equal(mean(out), 205.07)
+})
+
 test_that("using a formula", {
 
   set.seed(23426)
